survey

Function survey 

pub fn survey<'a, C: Container<Ref<'a>: Ord>>(
    lists0: <Lists<C> as Borrow>::Borrowed<'a>,
    lists1: <Lists<C> as Borrow>::Borrowed<'a>,
    reports: &[Report],
) -> Vec<Report>
From two sequences of interleaved lists, map out the interleaving of their values.

The sequence of input reports identify constraints on the sorted order of lists in the two inputs, callout out ranges of each that are exclusively order, and elements that have equal prefixes and therefore “overlap” and should be further investigated through the values of the lists.

The output should have the same form but for the next layer: subject to the ordering of reports, a similar report for the values of the two lists, appropriate for the next layer.