pub enum Report {
This(usize, usize),
That(usize, usize),
Both(usize, usize),
}Expand description
A report we would expect to see in a sequence about two layers.
A sequence of these reports reveal an ordered traversal of the keys of two layers, with ranges exclusive to one, ranges exclusive to the other, and individual elements (not ranges) common to both.
Variants
This(usize, usize)
Range of indices in this input.
That(usize, usize)
Range of indices in that input.
Both(usize, usize)
Matching indices in both inputs.