pub fn write_diffs<U: ColumnarUpdate>(
diffs0: <Lists<ContainerOf<U::Diff>> as Borrow>::Borrowed<'_>,
diffs1: <Lists<ContainerOf<U::Diff>> as Borrow>::Borrowed<'_>,
time_survey: &[Report],
output: &mut Lists<ContainerOf<U::Diff>>,
)Expand description
Write the diff layer from a time survey and two diff inputs.
The time survey is the item-level survey for the time layer, which doubles as the list survey for diffs (one diff list per time entry).
This(lo, hi): bulk-copy diff lists from input 0.That(lo, hi): bulk-copy diff lists from input 1.Both(t0, t1): consolidate the two singleton diffs. Push[sum]if non-zero, or an empty list[]if they cancel.